/*************************************************************************
**  File Name    : LCD.h
**  Version      : 1.0
**  Description  : LCD defines and prototypes
**  Author(s)    : Curt Lagerstam
**  Target(s)    : PIC32MX360512L
**  Compiler     : XC32
**  IDE          : Microchip MPLAB X IDE v9
**  Programmer   : PICKit3
**  Revisions    : Sep 26 2013
*************************************************************************/
#define UCHAR unsigned char

// LED Macros
#define mSetAllLedsON()         (mSetLed1ON(), mSetLed2ON(), mSetLed3ON())
#define mSetAllLedsOFF()        (mSetLed1OFF(), mSetLed2OFF(), mSetLed3OFF())
#define mSetAllLedsINV()        (mSetLed1INV(), mSetLed2INV(), mSetLed3INV())
#define mSetLed1ON()            mPORTDSetBits(BIT_0)
#define mSetLed1OFF()           mPORTDClearBits(BIT_0)
#define mSetLed1INV()           mPORTDToggleBits(BIT_0)
#define mSetLed2ON()            mPORTDSetBits(BIT_1)
#define mSetLed2OFF()           mPORTDClearBits(BIT_1)
#define mSetLed2INV()           mPORTDToggleBits(BIT_1)
#define mSetLed3ON()            mPORTDSetBits(BIT_2)
#define mSetLed3OFF()           mPORTDClearBits(BIT_2)
#define mSetLed3INV()           mPORTDToggleBits(BIT_2)

// Switch Macros
#define mReadSwitch1()          (!mPORTDReadBits(BIT_6))
#define mReadSwitch2()          (!mPORTDReadBits(BIT_7))
#define mReadSwitch3()          (!mPORTDReadBits(BIT_13))

typedef union
{
    struct
    {
        BYTE    Switch1:        1;
        BYTE    Switch2:        1;
        BYTE    Switch3:        1;
    };
    BYTE val;
}NHDEV_SWITCHES;

extern NHDEV_SWITCHES   press;
extern NHDEV_SWITCHES   switches;
#define mGetSwitch1()           (press.Switch1)
#define mGetSwitch2()           (press.Switch2)
#define mGetSwitch3()           (press.Switch3)

// LCD control pins Macros
#define mResetON()              mPORTGSetBits(BIT_15)
#define mResetOFF()             mPORTGClearBits(BIT_15)
#define CS1inactive()           mPORTGSetBits(BIT_12)
#define CS1active()             mPORTGClearBits(BIT_12)
#define RDinactive()            mPORTGSetBits(BIT_14)
#define RDactive()              mPORTGClearBits(BIT_14)
#define WRinactive()            mPORTCSetBits(BIT_4)
#define WRactive()              mPORTCClearBits(BIT_4)
#define LCD_DATA_ADDR           0x8001  // D/I high
#define LCD_CMD_ADDR            0x8000  // D/I low
#define LCD_CMD(X)              WRactive();PMPSetAddress(LCD_CMD_ADDR); while(mIsPMPBusy()); PMPMasterWrite(X);delay_us(150);WRinactive();
#define LCD_DATA(X)             WRactive();PMPSetAddress(LCD_DATA_ADDR); while(mIsPMPBusy());PMPMasterWrite(X);WRinactive();
#define RED                     0xFF0000
#define GREEN                   0x00FF00
#define BLUE                    0x0000FF
#define WHITE                   0xFFFFFF
#define BLACK                   0x000000


void Initialize(void);
void Soft_Reset(void);
void Exit_Sleep_Mode(void);
void Enter_Normal_Mode(void);
void Set_Gamma_Curve(UCHAR a);
void Set_F2(UCHAR a);
void Frame_Rate_Control(UCHAR a, UCHAR b);
void Power_Control_1(UCHAR a, UCHAR b);
void Power_Control_2(UCHAR a);
void VCOM_Control_1(UCHAR a, UCHAR b);
void VCOM_Offset_Control(UCHAR a);
void Memory_Access_Control(UCHAR a);
void Set_Pixel_Format(UCHAR a);
void Set_Display_Off(void);
void Set_Display_On(void);
void Write_Memory_Start(void);
void Set_Column_Address(UCHAR a, UCHAR b, UCHAR c, UCHAR d);
void Set_Page_Address(UCHAR a, UCHAR b, UCHAR c, UCHAR d);
void Fill_Color(int a);
void LCD_Pixel(int color);
void LCD_Text(UCHAR row, UCHAR column, UCHAR letter, int color);
void LCD_String(UCHAR row, UCHAR column, UCHAR *pointer, int color);
void Fill_Bars(void);