/*************************************************************************
**  File Name    : main.c
**  Version      : 1.0
**  Description  : Program for NHD-1.8-128160EF 1.8" TFT module with ILI9163 controller
**  Author(s)    : Curt Lagerstam
**  Target(s)    : PIC32MX360512L
**  Compiler     : XC32
**  IDE          : Microchip MPLAB X IDE v9
**  Programmer   : PICKit3
**  Revisions    : Sep 26 2013

(c)2013 Curt Lagerstam - Newhaven Display International, Inc.
        This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
*************************************************************************/

#include <plib.h>        /* PIC32 peripheral library */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <p32xxxx.h>
#include <GenericTypeDefs.h>
#include <math.h>
#include <wchar.h>
#include "main.h"  
#include "delay.h"
#include "LCD.h"

#pragma config FPLLMUL = MUL_20, FPLLIDIV = DIV_2, FPLLODIV = DIV_1, FWDTEN = OFF
#pragma config POSCMOD = HS, FNOSC = PRIPLL, FPBDIV = DIV_2

#define CONTROL (PMP_ON | PMP_IDLE_CON | PMP_MUX_OFF | PMP_ST | PMP_READ_WRITE_EN | PMP_LATCH_POL_HI | PMP_WRITE_POL_HI | PMP_READ_POL_HI)
#define MODE    (PMP_IRQ_OFF | PMP_AUTO_ADDR_OFF | PMP_DATA_BUS_8 | PMP_MODE_MASTER1 | PMP_WAIT_BEG_2 | PMP_WAIT_MID_15 | PMP_WAIT_END_4 )
#define PORT    (PMP_PEN_ALL)
#define INT     (PMP_INT_OFF)


////////// Initialize routine //////////
void InitPIC32(void)
{
    mSetAllLedsOFF();// Turn All Led's Off
    PORTSetPinsDigitalOut(IOPORT_D, BIT_0 | BIT_1 | BIT_2);// Set LED Pins to Outputs
    PORTSetPinsDigitalIn(IOPORT_D, BIT_6 | BIT_7 | BIT_13);// Set Switch Pins to Inputs
    CNPUE = 0x98000;// Enable Pull-ups
    PORTSetPinsDigitalOut(IOPORT_G, BIT_12 | BIT_14 | BIT_15);// Set CS, RD, RES Pin to Output
    PORTSetPinsDigitalOut(IOPORT_C, BIT_4);//WR
    mPMPOpen(CONTROL, MODE, PORT, INT);
    delay_us(30000);
    INTDisableInterrupts();
}

int main(void)
{
    int color = 0x000000;
    int count = 0;
    unsigned char HelloWorld[] = {40,69,76,76,79,96,55,79,82,76,68,1,0};//Hello World!
    unsigned char Newhaven[] = {46,69,87,72,65,86,69,78,96,36,73,83,80,76,65,89,0};//Newhaven Display

    SYSTEMConfigWaitStates(SYS_FREQ);// Set Periph Bus Divider 80MHz / 2 = 40MHz Fpb
    InitPIC32();
    mResetOFF();//hard reset LCD
    delay_us(100000);
    mResetON();//end hard reset
    mSetAllLedsOFF();// Turn All Led's Off

    Initialize();//initialize TFT
    CS1active();//set CS active
    RDinactive();//set RD inactive
    
    while(1)
    {
        Fill_Color(WHITE);
        LCD_String(16,16,Newhaven,BLUE);
        delay_us(500000);
        LCD_String(32,16,HelloWorld,RED);
        delay_us(2000000);
        Fill_Bars();
        delay_us(2000000);
    };
    return (EXIT_SUCCESS);
}

